@@ -23,7 +23,6 @@ import os
 import subprocess
 from typing import Any, Dict, Optional
 
-import jinja2
 import nr.fs  # type: ignore
 from termcolor import colored
 
@@ -41,11 +40,11 @@ build/
 '''.lstrip()
 
 README_TEMPLATE = '''
-# {{project_name}}
+# ${project_name}
 
 ---
 
-<p align="center">Copyright &copy; {{year}} {{author.name}}</p>
+<p align="center">Copyright &copy; ${year} ${author.name}</p>
 '''.lstrip()
 
 
@@ -71,12 +70,6 @@ def get_license_file_text(license: str, template_vars: Dict[str, Any]) -> str:
   return license_text
 
 
-def render_template(fp, template_string, template_vars):
-  for data in jinja2.Template(template_string).stream(**template_vars):
-    fp.write(data)
-  fp.write('\n')
-
-
 def write_files(
   files: VirtualFiles,
   target_directory: str,
